@@ -24,7 +24,7 @@ class Execution:
     time: datetime
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         data["execution_type"] = self.execution_type.value()
         data["time"] = datetime_to_str(self.time)
