@@ -18,7 +18,7 @@ class Investor:
     tracking_stocks: Set[str] = field(default_factory=set)
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         for a_set in ["symbols_held", "default_stocks", "tracking_stocks"]:
             data[a_set] = list(data[a_set])
