@@ -26,7 +26,7 @@ class News:
     related_instruments: List[str]
     preview_text: str
     currency_id: str
-    other: field(default_factory=dict)
+    other: Dict[str, str] = field(default_factory=dict)
 
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> News:
