@@ -36,7 +36,7 @@ class OptionalOrder:
     detail: Optional[str] = None
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         if self.order is not None:
             data["order"] = self.order.serialize()
@@ -66,10 +66,10 @@ class OrderExecution:
     quantity: float
     settlement_date: datetime
     timestamp: datetime
-    other: field(default_factory=dict)
+    other: Dict[str, str] = field(default_factory=dict)
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         data["settlement_date"] = datetime_to_str(self.settlement_date)
         data["timestamp"] = datetime_to_str(self.timestamp)
@@ -139,12 +139,12 @@ class Order:
     ipo_access_upper_price: float
     ipo_access_lower_price: float
     ipo_access_cancellation_reason: str
-    other: field(default_factory=dict)
     details: Optional[str] = None
     is_ipo_access_price_finalized: Optional[bool] = None
+    other: Dict[str, str] = field(default_factory=dict)
 
     def serialize(self) -> Dict[str, Any]:
-        data: Dict[str, Any] = self.__dict__
+        data: Dict[str, Any] = deepcopy(self.__dict__)
 
         data["state"] = self.state.value()
         data["time_in_force"] = self.time_in_force.value()
