@@ -31,8 +31,8 @@ class Position:
     url: str
     account: str
     account_number: str
-    other: field(default_factory=dict)
     shares_available_for_closing_short_position: float = 0.00
+    other: Dict[str, str] = field(default_factory=dict)
 
     def serialize(self) -> Dict[str, Any]:
         data = deepcopy(self.__dict__)
