@@ -124,13 +124,29 @@ def readable_date_to_str(a_date: datetime = to_est(), format_str: str = "%Y-%m-%
 
 
 def time_offset(seconds: int, a_datetime=to_est()) -> datetime:
-    """Provides a minute representation.
+    """Offset in seconds from a time.
 
-    Returns: a datetime
+    Args:
+        seconds: seconds to offset
+        a_datetime: time
+
+    Returns: offset time
     """
     return a_datetime - timedelta(seconds=seconds)
 
 
+def time_offset_in_days(days: int, a_datetime=to_est()) -> datetime:
+    """Offset in days from a time.
+
+    Args:
+        days: days to offset
+        a_datetime: time
+
+    Returns: offset time
+    """
+    return a_datetime - timedelta(days=days)
+
+
 def timeoffset_as_str(seconds: int, a_datetime=to_est()) -> str:
     """Provides a minute representation.
 
